==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RecreateDeploymentStrategyParamsFluent<A extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMid instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getMid();
  public io.fabric8.openshift.api.model.LifecycleHook buildMid();
  public A withMid(io.fabric8.openshift.api.model.LifecycleHook mid);
  public java.lang.Boolean hasMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost();
  public io.fabric8.openshift.api.model.LifecycleHook buildPost();
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post);
  public java.lang.Boolean hasPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre();
  public io.fabric8.openshift.api.model.LifecycleHook buildPre();
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre);
  public java.lang.Boolean hasPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public java.lang.Long getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public interface MidNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>>{
    public N and();
    public N endMid();
    
  }
  public interface PostNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/RecreateDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RecreateDeploymentStrategyParamsFluent<A extends io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMid instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getMid();
  public io.fabric8.openshift.api.model.LifecycleHook buildMid();
  public A withMid(io.fabric8.openshift.api.model.LifecycleHook mid);
  public java.lang.Boolean hasMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> withNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMid();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<A> editOrNewMidLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPost();
  public io.fabric8.openshift.api.model.LifecycleHook buildPost();
  public A withPost(io.fabric8.openshift.api.model.LifecycleHook post);
  public java.lang.Boolean hasPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(io.fabric8.openshift.api.model.LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.LifecycleHook getPre();
  public io.fabric8.openshift.api.model.LifecycleHook buildPre();
  public A withPre(io.fabric8.openshift.api.model.LifecycleHook pre);
  public java.lang.Boolean hasPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(io.fabric8.openshift.api.model.LifecycleHook item);
  public java.lang.Long getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Long timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MidNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.MidNested<N>>{
    public N and();
    public N endMid();
    
  }
  public interface PostNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.LifecycleHookFluent<io.fabric8.openshift.api.model.RecreateDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}
